From: "Jonathan Callen" <abcd@gentoo.org>
To: gentoo-commits@lists.gentoo.org
Subject: [gentoo-commits] proj/kde:master commit in: Documentation/maintainers/
Date: Sat, 5 Mar 2011 19:58:50 +0000 (UTC) [thread overview]
Message-ID: <8fc3c913ed09072b127679ea7f26ee43ba3f265a.abcd@gentoo> (raw)
commit: 8fc3c913ed09072b127679ea7f26ee43ba3f265a
Author: abcd <abcd <AT> gentoo <DOT> org>
AuthorDate: Sat Mar 5 19:58:43 2011 +0000
Commit: Jonathan Callen <abcd <AT> gentoo <DOT> org>
CommitDate: Sat Mar 5 19:58:43 2011 +0000
URL: http://git.overlays.gentoo.org/gitweb/?p=proj/kde.git;a=commit;h=8fc3c913
[Documentation] Auto-keyword for ~x86-linux and ~amd64-linux
---
Documentation/maintainers/bump_new_revision.sh | 14 ++++++--------
1 files changed, 6 insertions(+), 8 deletions(-)
diff --git a/Documentation/maintainers/bump_new_revision.sh b/Documentation/maintainers/bump_new_revision.sh
index d14de0a..1af095e 100755
--- a/Documentation/maintainers/bump_new_revision.sh
+++ b/Documentation/maintainers/bump_new_revision.sh
@@ -87,18 +87,18 @@ check_cmakelists() {
# Updates keywords:
# - for stable releases - use latest keywords from tree
# - for snapshot/alpha/beta/rc releases - use fixed ~amd64 and ~x86 keywords
# - in either case drop arch to testing
update_keywords() {
- local MINIMAL_KEYWORDS="~amd64 ~x86"
+ local MINIMAL_KEYWORDS="~amd64 ~x86 ~amd64-linux ~x86-linux" KEYWORDS
# Initially strip all keywords
ekeyword ^all ${1} > /dev/null
if [[ ${BUMP_VERSION} =~ ([4-9]+)\.?([0-9]*)\.?([0-9]*) ]]; then
local version_major=${BASH_REMATCH[1]}
local version_minor=${BASH_REMATCH[2]}
local version_patch=${BASH_REMATCH[3]}
- if [[ -n {version_patch} ]]; then
- if [[ ${version_patch} -lt 50 ]]; then
+ if [[ -n ${version_patch} ]]; then
+ if (( version_patch < 50 )); then
# Patch version is < 50 - stable release, try to obtain keywords from tree
if pushd "$(portageq portdir)/${2}" &> /dev/null; then
KEYWORDS=$(ls -1r *-4*.ebuild | grep -v ${BUMP_VERSION} | head -n 1 | xargs sed -ne 's/^KEYWORDS="\(.*\)"/\1/p')
@@ -107,7 +107,7 @@ update_keywords() {
KEYWORDS=${MINIMAL_KEYWORDS}
fi
popd &> /dev/null
- elif [[ ${version_patch} -le 99 ]]; then
+ elif (( version_patch <= 99 )); then
# Patch version >= 50 and <= 99 - snapshot/alpha/beta/rc release, ~amd64 ~x86 keywords
KEYWORDS=${MINIMAL_KEYWORDS}
fi
@@ -184,11 +184,10 @@ SLOT=
VERSION=
OPERATION=
BUMP_VERSION=
-KEYWORDS=
SET=
DIR=
OUTPUT_DIR=
-while getopts a:s:v:b:l:p:o:n arg ; do
+while getopts a:s:v:b:l:p:o arg ; do
case ${arg} in
a) OPERATION=${OPTARG} ;;
s) SLOT=${OPTARG} ;;
@@ -197,7 +196,6 @@ while getopts a:s:v:b:l:p:o:n arg ; do
l) SET="${OPTARG}" ;;
p) DIR="${OPTARG}" ;;
o) OUTPUT_DIR="${OPTARG}" ;;
- n) KEYWORDS="no" ;;
*) help ;;
?) help ;;
esac
next reply other threads:[~2011-03-05 19:58 UTC|newest]
Thread overview: 117+ messages / expand[flat|nested] mbox.gz Atom feed top
2011-03-05 19:58 Jonathan Callen [this message]
-- strict thread matches above, loose matches on Subject: below --
2024-10-04 22:21 [gentoo-commits] proj/kde:master commit in: Documentation/maintainers/ Andreas Sturmlechner
2024-10-04 22:21 Andreas Sturmlechner
2024-10-01 18:09 Andreas Sturmlechner
2024-10-01 18:09 Andreas Sturmlechner
2024-09-07 12:00 Andreas Sturmlechner
2024-09-07 9:59 Andreas Sturmlechner
2024-09-02 9:31 Andreas Sturmlechner
2024-08-23 19:25 Andreas Sturmlechner
2024-02-24 2:30 Maciej Mrozowski
2024-01-13 16:39 Sam James
2024-01-07 19:10 Andreas Sturmlechner
2024-01-07 17:13 Andreas Sturmlechner
2023-12-16 22:02 Andreas Sturmlechner
2023-11-25 23:25 Andreas Sturmlechner
2023-07-24 13:32 Andreas Sturmlechner
2023-05-25 20:36 Andreas Sturmlechner
2023-05-25 20:36 Andreas Sturmlechner
2023-03-23 22:10 Andreas Sturmlechner
2023-02-07 10:45 Andreas Sturmlechner
2022-12-11 21:24 Andreas Sturmlechner
2022-12-11 17:24 Andreas Sturmlechner
2022-12-05 18:33 Andreas Sturmlechner
2022-11-08 19:27 Andreas Sturmlechner
2022-10-16 11:03 Andreas Sturmlechner
2022-10-03 8:51 Andreas Sturmlechner
2022-07-19 14:24 Andreas Sturmlechner
2022-05-03 22:31 Sam James
2021-08-11 6:10 Andreas Sturmlechner
2021-06-14 8:24 Andreas Sturmlechner
2021-01-24 19:57 Andreas Sturmlechner
2021-01-11 12:38 Andreas Sturmlechner
2020-11-25 18:25 Andreas Sturmlechner
2020-10-09 13:51 Andreas Sturmlechner
2020-06-22 19:53 Andreas Sturmlechner
2020-06-22 19:53 Andreas Sturmlechner
2020-06-22 18:21 Andreas Sturmlechner
2020-06-22 18:21 Andreas Sturmlechner
2020-06-01 10:03 Andreas Sturmlechner
2020-03-19 0:54 Andreas Sturmlechner
2020-03-15 22:27 Andreas Sturmlechner
2020-03-01 12:33 Andreas Sturmlechner
2019-12-23 20:52 Andreas Sturmlechner
2019-12-08 8:56 Andreas Sturmlechner
2018-10-18 21:00 Andreas Sturmlechner
2018-02-22 19:14 Andreas Sturmlechner
2018-02-06 10:15 Andreas Sturmlechner
2017-12-28 13:43 Michael Palimaka
2017-12-28 13:43 Michael Palimaka
2017-12-26 3:27 Michael Palimaka
2017-08-14 18:55 Andreas Sturmlechner
2017-06-14 19:37 Johannes Huber
2017-05-24 20:37 Andreas Sturmlechner
2016-12-04 20:31 Johannes Huber
2016-11-13 17:51 Michael Palimaka
2016-07-31 19:48 Michael Palimaka
2016-07-23 12:03 Johannes Huber
2016-07-13 6:16 Johannes Huber
2016-06-30 20:39 Johannes Huber
2016-06-30 20:39 Johannes Huber
2016-06-30 20:39 Johannes Huber
2016-06-30 20:39 Johannes Huber
2016-06-30 20:39 Johannes Huber
2016-06-06 21:47 Johannes Huber
2016-04-24 12:47 Johannes Huber
2016-04-20 14:48 Michael Palimaka
2016-03-08 16:01 Johannes Huber
2015-08-09 9:00 Johannes Huber
2015-08-09 8:40 Johannes Huber
2015-06-08 10:21 Manuel Rüger
2015-06-08 10:21 Manuel Rüger
2015-06-08 10:14 Manuel Rüger
2015-04-05 19:41 Michael Palimaka
2015-04-05 19:39 Michael Palimaka
2015-04-05 19:04 Michael Palimaka
2015-04-05 18:33 Michael Palimaka
2014-12-14 15:21 Michael Palimaka
2014-11-07 11:23 Manuel Rüger
2014-09-26 17:25 Michael Palimaka
2014-09-26 16:59 Michael Palimaka
2014-09-26 16:03 Michael Palimaka
2014-09-17 16:36 Michael Palimaka
2014-08-24 9:48 Michael Palimaka
2014-08-24 9:48 Michael Palimaka
2014-08-24 8:46 Michael Palimaka
2014-08-12 11:05 Michael Palimaka
2014-07-22 17:52 Michael Palimaka
2014-05-09 17:27 Michael Palimaka
2014-02-12 14:18 Michael Palimaka
2014-02-06 23:26 Andreas Hüttel
2014-01-18 4:34 Robin H. Johnson
2014-01-06 1:25 Chris Reffett
2014-01-06 1:25 Chris Reffett
2013-12-03 23:09 Johannes Huber
2013-11-23 2:05 Maciej Mrozowski
2013-10-09 3:51 Chris Reffett
2013-06-25 16:39 Marc Schiffbauer
2013-04-15 9:50 Michael Palimaka
2012-12-19 22:13 Marc Schiffbauer
2012-11-16 16:54 Alexey Shvetsov
2012-09-11 20:21 Michael Palimaka
2012-08-07 13:20 Johannes Huber
2012-08-02 10:24 Johannes Huber
2012-06-21 22:01 Andreas Hüttel
2012-06-02 22:10 Andreas Hüttel
2012-06-02 22:10 Andreas Hüttel
2012-04-10 12:59 Dennis Schridde
2012-03-25 13:12 Dennis Schridde
2012-01-20 13:24 Johannes Huber
2011-12-09 14:29 Johannes Huber
2011-11-19 23:29 Alexey Shvetsov
2011-11-02 22:30 Alexey Shvetsov
2011-06-06 9:29 Jorge Manuel B. S. Vicetto
2011-04-28 8:14 Andreas K. Huettel
2011-04-27 18:09 Maciej Mrozowski
2011-04-27 15:48 Andreas K. Huettel
2011-02-13 17:32 Dennis Schridde
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=8fc3c913ed09072b127679ea7f26ee43ba3f265a.abcd@gentoo \
--to=abcd@gentoo.org \
--cc=gentoo-commits@lists.gentoo.org \
--cc=gentoo-dev@lists.gentoo.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -87,18 +87,18 @@ check_cmakelists() {
# Updates keywords:
# - for stable releases - use latest keywords from tree
-# - for snapshot/alpha/beta/rc releases - use fixed ~amd64 and ~x86 keywords
+# - for snapshot/alpha/beta/rc releases - use fixed ~amd64, ~x86 and ~{amd64,x86}-linux keywords
# - in either case drop arch to testing
update_keywords() {
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox